#libraries
library(tidyverse)
# wd (change)
setwd("~/Documents/Research/research_others/consult/08_us_polling/conditional")
#load data
sim <- data.frame(read_csv("electoral_college_simulations.csv"))
statenames <- read_csv("statenames.csv")
rep_voteshare <- read_csv("state_rep_voteshare.csv")
sim_rowmeans <- colMeans(sim)
pred_mean <- data.frame(state = names(sim_rowmeans)[4:length(sim_rowmeans)],
                        mean_pred = sim_rowmeans[4:length(sim_rowmeans)]) %>%
  arrange(mean_pred)
# create container
df <- matrix(NA, ncol = 13, nrow = 0)
# loopy
for (i in 4:ncol(sim)){
  # win
  tmp <- sim[sim[,i]>= 0.51,]
  add <- c(i, "win", 
           median(tmp$natl_pop_vote), 
           quantile(tmp$natl_pop_vote, c(0.25)), quantile(tmp$natl_pop_vote, c(0.75)),
           quantile(tmp$natl_pop_vote, c(0.025)), quantile(tmp$natl_pop_vote, c(0.975)),
           median(tmp$dem_ev), 
           quantile(tmp$dem_ev, c(0.25)), quantile(tmp$dem_ev, c(0.75)),
           quantile(tmp$dem_ev, c(0.025)), quantile(tmp$dem_ev, c(0.975)),
           dim(tmp)[1])
  df <- rbind(df, add)
  # loss
  tmp <- sim[sim[,i] <= 0.49,]
  add <- c(i, "loss", 
           median(tmp$natl_pop_vote), 
           quantile(tmp$natl_pop_vote, c(0.25)), quantile(tmp$natl_pop_vote, c(0.75)),
           quantile(tmp$natl_pop_vote, c(0.025)), quantile(tmp$natl_pop_vote, c(0.975)),
           median(tmp$dem_ev), 
           quantile(tmp$dem_ev, c(0.25)), quantile(tmp$dem_ev, c(0.75)),
           quantile(tmp$dem_ev, c(0.025)), quantile(tmp$dem_ev, c(0.975)),
           dim(tmp)[1])
  df <- rbind(df, add)
  # inbetween
  tmp <- sim[sim[,i] > 0.49 & sim[,i] < 0.51,]
  add <- c(i, "middle", 
           median(tmp$natl_pop_vote), 
           quantile(tmp$natl_pop_vote, c(0.25)), quantile(tmp$natl_pop_vote, c(0.75)),
           quantile(tmp$natl_pop_vote, c(0.025)), quantile(tmp$natl_pop_vote, c(0.975)),
           median(tmp$dem_ev), 
           quantile(tmp$dem_ev, c(0.25)), quantile(tmp$dem_ev, c(0.75)),
           quantile(tmp$dem_ev, c(0.025)), quantile(tmp$dem_ev, c(0.975)),
           dim(tmp)[1])
  df <- rbind(df, add)
}
df <- as.data.frame(df)
colnames(df) <- c("state", "outcome", "natpop_median", 
                  "natpop_q25", "natpop_q75", 
                  "natpop_q025", "natpop_q975",
                  "ec_median", 
                  "ec_q25", "ec_q75", 
                  "ec_q025", "ec_q975",
                  "sim")
rownames(df) <- NULL
df$state <- colnames(sim)[as.integer(as.character(df$state))]
df <- df %>% 
  mutate(natpop_median = as.numeric(as.character(natpop_median)),
         natpop_q25 = as.numeric(as.character(natpop_q25)),
         natpop_q75 = as.numeric(as.character(natpop_q75)),
         natpop_q025 = as.numeric(as.character(natpop_q025)),
         natpop_q975 = as.numeric(as.character(natpop_q975)),
         ec_median = as.numeric(as.character(ec_median)),
         ec_q25 = as.numeric(as.character(ec_q25)),
         ec_q75 = as.numeric(as.character(ec_q75)),
         ec_q025 = as.numeric(as.character(ec_q025)),
         ec_q975 = as.numeric(as.character(ec_q975)),
         sim = as.numeric(as.character(sim))
         ) %>%
  left_join(statenames, by = c("state" = "Code")) %>%
  left_join(rep_voteshare, by = c("state" = "State")) %>% # give Andrew his full state names %>%
  mutate(state_sim = paste0(State, " - ", sprintf("%.2f",round(sim/40000, 2))),
         natpop_median = ifelse(sim < 400, NA, natpop_median),
         ec_median = ifelse(sim < 400, NA, ec_median),
         natpop_q25 = ifelse(sim < 400, NA, natpop_q25),
         natpop_q75 = ifelse(sim < 400, NA, natpop_q75),
         natpop_q025 = ifelse(sim < 400, NA, natpop_q025),
         natpop_q975 = ifelse(sim < 400, NA, natpop_q975),
         ec_q25 = ifelse(sim < 400, NA, ec_q25),
         ec_q75 = ifelse(sim < 400, NA, ec_q75),
         ec_q025 = ifelse(sim < 400, NA, ec_q025),
         ec_q975 = ifelse(sim < 400, NA, ec_q975)) 
  
df <- df %>%
  mutate(state = factor(state, levels = pred_mean$state)) %>%
  arrange(state)
#national popular vote
natpop_loss <- ggplot(data = df %>% 
         filter(outcome == "loss")) + 
  geom_point(aes(x = state, y = natpop_median)) + 
  geom_errorbar(aes(x = state, ymax = natpop_q25, 
                    ymin = natpop_q75), width = 0, size = 1) + 
  geom_errorbar(aes(x = state, ymax = natpop_q025, 
                    ymin = natpop_q975), width = 0, size = 0.5) + 
  theme_bw() + 
  coord_flip() + 
  scale_x_discrete(labels= df %>% 
                     arrange(state) %>%
                   filter(outcome == "loss") %>% 
                     pull(state_sim)) + 
  geom_hline(yintercept = 0.5, linetype = 4, color = "red") +
  labs(y = "National popular vote", title = "Less/equal 49%", 
  caption = "Thick line: 50%
            Thin line: 95%") + 
  ylim(c(0.475, 0.6)) +
  theme(axis.title.y = element_blank())

natpop_win <- ggplot(data = df %>% 
         filter(outcome == "win")) + 
  geom_point(aes(x = state, y = natpop_median)) + 
  geom_errorbar(aes(x = state, ymax = natpop_q25, 
                    ymin = natpop_q75), width = 0, size = 1) + 
  geom_errorbar(aes(x = state, ymax = natpop_q025, 
                    ymin = natpop_q975), width = 0, size = 0.5) + 
  theme_bw() + 
  coord_flip() + 
  scale_x_discrete(labels= df %>% 
                     arrange(state) %>%
                     filter(outcome == "win") %>% 
                     pull(state_sim)) + 
  geom_hline(yintercept = 0.5, linetype = 4, color = "red") +
  labs(y = "National popular vote", title = "More/equal 51%", 
       caption = "Thick line: 50%
            Thin line: 95%") + 
  ylim(c(0.475, 0.6)) +
  theme(axis.title.y = element_blank())



natpop_middle <- ggplot(data = df %>% 
         filter(outcome == "middle")) + 
  geom_point(aes(x = state, y = natpop_median)) + 
  geom_errorbar(aes(x = state, ymax = natpop_q25, 
                    ymin = natpop_q75), width = 0, size = 1) + 
  geom_errorbar(aes(x = state, ymax = natpop_q025, 
                    ymin = natpop_q975), width = 0, size = 0.5) + 
  theme_bw() + 
  coord_flip() + 
  scale_x_discrete(labels= df %>% 
                     arrange(state) %>%
                     filter(outcome == "middle") %>% 
                     pull(state_sim)) + 
  geom_hline(yintercept = 0.5, linetype = 4, color = "red") +
  labs(y = "National popular vote", title = "Between 49 and 51%", 
       caption = "Thick line: 50%
            Thin line: 95%") + 
  ylim(c(0.475, 0.6)) +
  theme(axis.title.y = element_blank())
plt_natpop <- gridExtra::grid.arrange(natpop_loss, natpop_middle, natpop_win, ncol = 3)
ggsave(file = "natpop.jpeg", plt_natpop, width = 10, height = 6)
# EC
ec_loss <- ggplot(data = df %>% 
                        filter(outcome == "loss")) + 
  geom_point(aes(x = state, y = ec_median)) + 
  geom_errorbar(aes(x = state, ymax = ec_q25, 
                    ymin = ec_q75), width = 0, size = 1) + 
  geom_errorbar(aes(x = state, ymax = ec_q025, 
                    ymin = ec_q975), width = 0, size = 0.5) + 
  theme_bw() + 
  coord_flip()+ 
  scale_x_discrete(labels = df %>% 
                     arrange(state) %>%
                     filter(outcome == "loss") %>% 
                     pull(state_sim)) + 
  geom_hline(yintercept = 270, linetype = 4, color = "red") +
  labs(y = "EC votes", title = "Less/equal 49%", 
  caption = "Thick line: 50%
            Thin line: 95%") + 
  ylim(c(150, 475)) +
  theme(axis.title.y = element_blank())

ec_win <- ggplot(data = df %>% 
                   filter(outcome == "win")) + 
  geom_point(aes(x = state, y = ec_median)) + 
  geom_errorbar(aes(x = state, ymax = ec_q25, 
                    ymin = ec_q75), width = 0, size = 1) + 
  geom_errorbar(aes(x = state, ymax = ec_q025, 
                    ymin = ec_q975), width = 0, size = 0.5) + 
  theme_bw() + 
  coord_flip() + 
  scale_x_discrete(labels= df %>% 
                     arrange(state) %>%
                     filter(outcome == "win") %>% 
                     pull(state_sim)) + 
  geom_hline(yintercept = 270, linetype = 4, color = "red") +
  labs(y = "EC votes", title = "More/equal 51%", 
       caption = "Thick line: 50%
            Thin line: 95%") + 
  ylim(c(150, 475)) +
  theme(axis.title.y = element_blank())

ec_middle <- ggplot(data = df %>% 
                      filter(outcome == "middle")) + 
  geom_point(aes(x = state, y = ec_median)) + 
  geom_errorbar(aes(x = state, ymax = ec_q25, 
                    ymin = ec_q75), width = 0, size = 1) + 
  geom_errorbar(aes(x = state, ymax = ec_q025, 
                    ymin = ec_q975), width = 0, size = 0.5) + 
  theme_bw() + 
  coord_flip() + 
  scale_x_discrete(labels= df %>% 
                     arrange(state) %>%
                     filter(outcome == "middle") %>% 
                     pull(state_sim)) + 
  geom_hline(yintercept = 270, linetype = 4, color = "red") +
  labs(y = "EC votes", title = "Between 49 and 51%", 
       caption = "Thick line: 50%
            Thin line: 95%") + 
  ylim(c(150, 475)) +
  theme(axis.title.y = element_blank())
plt_ec <- gridExtra::grid.arrange(ec_loss, ec_middle, ec_win, ncol = 3)
ggsave(file = "ec.jpeg", plt_ec, width = 10, height = 6)









